<?php

namespace Drupal\hubspot_integration\Cache\Context;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Cache\Context\CacheContextInterface;
use Drupal\hubspot_integration\Services\HubspotAPI;

/**
 * Définit un contexte de cache spécifique pour le module hubspot_integration.
 * 
 * Cache context ID: 'hubspot_cache_context'.
 */
class HubspotCacheContext implements CacheContextInterface {
  
  /**
   * Le contexte
   *
   * @const string
   */
  const CONTEXT_ID = 'hubspot_cache_context';
  
  /** @var \Drupal\hubspot_integration\Services\HubspotAPI $hubspot_api */
  protected $hubspot_api;
  
  /**
   * Constructs a new HubspotAPI object.
   * @param \Drupal\hubspot_integration\Services\HubspotAPI $hubspot_api
   */
  public function __construct(HubspotAPI $hubspot_api) {
    $this->hubspot_api = $hubspot_api;
  }
  
  /**
   * Retourne le service
   * 
   * @return static
   *   Le service.
   */
  public static function me(){
    return \Drupal::service('cache_context.hubspot_cache_context');
  }

  /**
   * {@inheritdoc}
   */
  public static function getLabel() {
    return t('Cache contexte sur les termes appliqué a un utilisateur.');
  }

  /**
   * Renvoie l'identifiant de contexte courant.
   * 
   * On renvoie un identifiant de contexte différent 
   * 1 si on est entre 3h et 17h59
   * 0 si on est entre 18h et 2h59h
   *
   * {@inheritdoc}
   */
  public function getContext() {
    // Si des paramètres d'urls sont passé, on renvoi params.
    $hubspot_api = $this->hubspot_api;
    $tids = $hubspot_api->getUserTids();
    return 'hubspot_'.implode('_', $tids);
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheableMetadata() {
    return new CacheableMetadata();
  }
}